@@ -1,3 +1,6 @@
+/*
+ * SPDX-License-Identifier: LGPL-2.1
+ */
 #define TSLIB_DECLARE_MODULE(name) \
 	TSAPI struct tslib_module_info *name##_mod_init(struct tsdev *dev, const char *params)
 
@@ -10,6 +13,7 @@ TSLIB_DECLARE_MODULE(pthres);
 TSLIB_DECLARE_MODULE(debounce);
 TSLIB_DECLARE_MODULE(skip);
 TSLIB_DECLARE_MODULE(iir);
+TSLIB_DECLARE_MODULE(lowpass);
 
 TSLIB_DECLARE_MODULE(arctic2);
 TSLIB_DECLARE_MODULE(collie);
