@@ -6,6 +6,8 @@
  * This file is placed under the LGPL.  Please see the file
  * COPYING for more details.
  *
+ * SPDX-License-Identifier: LGPL-2.1
+ *
  *
  * Share and static plugin-modules loading functions
  */
@@ -76,6 +78,9 @@ static const struct tslib_module_desc tslib_modules[] = {
 #ifdef TSLIB_STATIC_LINEAR_H2200_MODULE
 	{ "linear_h2200", linear_h2200_mod_init },
 #endif
+#ifdef TSLIB_STATIC_LOWPASS_MODULE
+	{ "lowpass", lowpass_mod_init },
+#endif
 #ifdef TSLIB_STATIC_MEDIAN_MODULE
 	{ "median", median_mod_init },
 #endif
